@@ -72,7 +72,6 @@
 
 BEGIN_EVENT_TABLE( EDA_DRAW_FRAME, KIWAY_PLAYER )
     EVT_UPDATE_UI( ID_ON_GRID_SELECT, EDA_DRAW_FRAME::OnUpdateSelectGrid )
-    EVT_UPDATE_UI( ID_ON_ZOOM_SELECT, EDA_DRAW_FRAME::OnUpdateSelectZoom )
 
     EVT_ACTIVATE( EDA_DRAW_FRAME::onActivate )
 END_EVENT_TABLE()
@@ -267,11 +266,20 @@ void EDA_DRAW_FRAME::unitsChangeRefresh()
 
 void EDA_DRAW_FRAME::ToggleUserUnits()
 {
-    SetUserUnits( m_userUnits == EDA_UNITS::INCHES ? EDA_UNITS::MILLIMETRES : EDA_UNITS::INCHES );
-    unitsChangeRefresh();
+    if( m_toolManager->GetTool<COMMON_TOOLS>() )
+    {
+        TOOL_EVENT dummy;
+        m_toolManager->GetTool<COMMON_TOOLS>()->ToggleUnits( dummy );
+    }
+    else
+    {
+        SetUserUnits( m_userUnits == EDA_UNITS::INCHES ? EDA_UNITS::MILLIMETRES
+                                                       : EDA_UNITS::INCHES );
+        unitsChangeRefresh();
 
-    wxCommandEvent e( UNITS_CHANGED );
-    ProcessEventLocally( e );
+        wxCommandEvent e( UNITS_CHANGED );
+        ProcessEventLocally( e );
+    }
 }
 
 
@@ -348,7 +356,7 @@ void EDA_DRAW_FRAME::PrintPage( const RENDER_SETTINGS* aSettings )
 
 void EDA_DRAW_FRAME::OnSelectGrid( wxCommandEvent& event )
 {
-    wxCHECK_RET( m_gridSelectBox, "m_gridSelectBox uninitialized" );
+    wxCHECK_RET( m_gridSelectBox, wxT( "m_gridSelectBox uninitialized" ) );
 
     int idx = m_gridSelectBox->GetCurrentSelection();
 
@@ -443,33 +451,9 @@ void EDA_DRAW_FRAME::UpdateZoomSelectBox()
 }
 
 
-void EDA_DRAW_FRAME::OnUpdateSelectZoom( wxUpdateUIEvent& aEvent )
-{
-    if( m_zoomSelectBox == nullptr || m_zoomSelectBox->GetParent() == nullptr )
-        return;
-
-    int current = 0;    // display Auto if no match found
-
-    // check for a match within 1%
-    double zoom = GetCanvas()->GetGAL()->GetZoomFactor();
-
-    for( unsigned i = 0; i < config()->m_Window.zoom_factors.size(); i++ )
-    {
-        if( std::fabs( zoom - config()->m_Window.zoom_factors[i] ) < ( zoom / 100.0 ) )
-        {
-            current = i + 1;
-            break;
-        }
-    }
-
-    if( current != m_zoomSelectBox->GetSelection() )
-        m_zoomSelectBox->SetSelection( current );
-}
-
-
 void EDA_DRAW_FRAME::OnSelectZoom( wxCommandEvent& event )
 {
-    wxCHECK_RET( m_zoomSelectBox, "m_zoomSelectBox uninitialized" );
+    wxCHECK_RET( m_zoomSelectBox, wxT( "m_zoomSelectBox uninitialized" ) );
 
     int id = m_zoomSelectBox->GetCurrentSelection();
 
@@ -514,7 +498,7 @@ void EDA_DRAW_FRAME::AddStandardSubMenus( TOOL_MENU& aToolMenu )
     gridMenu->SetTool( commonTools );
     aToolMenu.AddSubMenu( gridMenu );
 
-    aMenu.AddMenu( zoomMenu.get(),   SELECTION_CONDITIONS::ShowAlways, 1000 );
+    aMenu.AddMenu( zoomMenu.get(), SELECTION_CONDITIONS::ShowAlways, 1000 );
     aMenu.AddMenu( gridMenu.get(), SELECTION_CONDITIONS::ShowAlways, 1000 );
 }
 
@@ -535,7 +519,7 @@ void EDA_DRAW_FRAME::DisplayGridMsg()
 {
     wxString line;
 
-    line.Printf( "grid %s",
+    line.Printf( wxT( "grid %s" ),
                  MessageTextFromValue( GetUserUnits(), GetCanvas()->GetGAL()->GetGridSize().x,
                                        false ) );
 
@@ -710,7 +694,7 @@ void EDA_DRAW_FRAME::SetMsgPanel( EDA_ITEM* aItem )
 
 void EDA_DRAW_FRAME::UpdateMsgPanel()
 {
-    GetToolManager()->PostEvent( EVENTS::SelectedItemsModified );
+    GetToolManager()->ProcessEvent( EVENTS::SelectedItemsModified );
 }
 
 
@@ -979,18 +963,22 @@ bool EDA_DRAW_FRAME::LibraryFileBrowser( bool doOpen, wxFileName& aFilename,
     wxString prompt = doOpen ? _( "Select Library" ) : _( "New Library" );
     aFilename.SetExt( ext );
 
-    wxString dir = aGlobalPath;
+    wxString dir;
+
+    if( GetMruPath().IsEmpty() )
+        dir = aGlobalPath;
+    else
+        dir = GetMruPath();
 
 
     if( isDirectory && doOpen )
     {
-        if( !aIsGlobal )
+        if( !aIsGlobal && GetMruPath().IsEmpty() )
         {
             dir = Prj().GetProjectPath();
         }
 
-        wxDirDialog dlg( this, prompt, dir,
-                         wxDD_DEFAULT_STYLE | wxDD_DIR_MUST_EXIST );
+        wxDirDialog dlg( this, prompt, dir, wxDD_DEFAULT_STYLE | wxDD_DIR_MUST_EXIST );
 
         if( dlg.ShowModal() == wxID_CANCEL )
             return false;
@@ -1002,9 +990,9 @@ bool EDA_DRAW_FRAME::LibraryFileBrowser( bool doOpen, wxFileName& aFilename,
     {
         // Ensure the file has a dummy name, otherwise GTK will display the regex from the filter
         if( aFilename.GetName().empty() )
-            aFilename.SetName( "Library" );
+            aFilename.SetName( wxT( "Library" ) );
 
-        if( !aIsGlobal )
+        if( !aIsGlobal && GetMruPath().IsEmpty() )
         {
             dir = Prj().IsNullProject() ? aFilename.GetFullPath() : Prj().GetProjectPath();
         }
@@ -1020,6 +1008,8 @@ bool EDA_DRAW_FRAME::LibraryFileBrowser( bool doOpen, wxFileName& aFilename,
         aFilename.SetExt( ext );
     }
 
+    SetMruPath( aFilename.GetPath() );
+
     return true;
 }
 
