@@ -502,7 +502,7 @@ void FIELDS_GRID_TABLE<T>::SetValue( int aRow, int aCol, const wxString &aValue
                 value = fn.GetFullPath();
             }
         }
-        else if( m_frame->IsType( FRAME_SCH_SYMBOL_EDITOR ) && aRow == VALUE_FIELD )
+        else if( m_parentType == SCH_SYMBOL_T && aRow == VALUE_FIELD )
         {
             value = EscapeString( value, CTX_LIBID );
         }
@@ -669,18 +669,18 @@ wxString FIELDS_GRID_TABLE<T>::StringFromBool( bool aValue ) const
 template <class T>
 bool FIELDS_GRID_TABLE<T>::BoolFromString( wxString aValue ) const
 {
-    if( aValue == "1" )
+    if( aValue == wxT( "1" ) )
     {
         return true;
     }
-    else if( aValue == "0" )
+    else if( aValue == wxT( "0" ) )
     {
         return false;
     }
     else
     {
-        wxFAIL_MSG( wxString::Format( "string '%s' can't be converted to boolean "
-                                      "correctly, it will have been perceived as FALSE", aValue ) );
+        wxFAIL_MSG( wxString::Format( wxT( "string '%s' can't be converted to boolean " )
+                                      wxT( "correctly, it will have been perceived as FALSE" ), aValue ) );
         return false;
     }
 }
