@@ -339,9 +339,32 @@ int BOARD_EDITOR_CONTROL::PageSettings( const TOOL_EVENT& aEvent )
     dlg.SetWksFileName( BASE_SCREEN::m_DrawingSheetFileName );
 
     if( dlg.ShowModal() == wxID_OK )
+    {
+        m_frame->GetCanvas()->GetView()->UpdateAllItemsConditionally( KIGFX::REPAINT,
+                [&]( KIGFX::VIEW_ITEM* aItem ) -> bool
+                {
+                    BOARD_ITEM* item = dynamic_cast<BOARD_ITEM*>( aItem );
+
+                    if( !item )
+                        return false;
+
+                    switch( item->Type() )
+                    {
+                    case PCB_TEXT_T:
+                    case PCB_FP_TEXT_T:
+                        return true;        // text variables
+
+                    default:
+                        return false;
+                    }
+                } );
+
         m_frame->OnModify();
+    }
     else
+    {
         m_frame->RollbackFromUndo();
+    }
 
     return 0;
 }
@@ -441,7 +464,7 @@ int BOARD_EDITOR_CONTROL::ExportNetlist( const TOOL_EVENT& aEvent )
 
     // Use a different file extension for the board netlist so the schematic netlist file
     // is accidentally overwritten.
-    fn.SetExt( "pcb_net" );
+    fn.SetExt( wxT( "pcb_net" ) );
 
     wxFileDialog dlg( m_frame, _( "Export Board Netlist" ), fn.GetPath(), fn.GetFullName(),
                       _( "KiCad board netlist files" ) + AddFileExtListToFilter( { "pcb_net" } ),
@@ -510,7 +533,7 @@ int BOARD_EDITOR_CONTROL::GenerateFabFiles( const TOOL_EVENT& aEvent )
     else if( aEvent.IsAction( &PCB_ACTIONS::generateBOM ) )
         m_frame->RecreateBOMFileFromBoard( dummy );
     else
-        wxFAIL_MSG( "GenerateFabFiles(): unexpected request" );
+        wxFAIL_MSG( wxT( "GenerateFabFiles(): unexpected request" ) );
 
     return 0;
 }
@@ -651,10 +674,10 @@ int BOARD_EDITOR_CONTROL::UpdateSchematicFromPCB( const TOOL_EVENT& aEvent )
 {
     if( Kiface().IsSingle() )
     {
-        DisplayErrorMessage(
-                m_frame, _( "Cannot update schematic because Pcbnew is opened in stand-alone "
-                            "mode. In order to create or update PCBs from schematics, you "
-                            "must launch the KiCad project manager and create a project." ) );
+        DisplayErrorMessage( m_frame, _( "Cannot update schematic because Pcbnew is opened in "
+                                         "stand-alone mode. In order to create or update PCBs "
+                                         "from schematics, you must launch the KiCad project "
+                                         "manager and create a project." ) );
         return 0;
     }
 
@@ -723,7 +746,7 @@ int BOARD_EDITOR_CONTROL::TrackWidthInc( const TOOL_EVENT& aEvent )
             }
         }
 
-        commit.Push( "Increase Track Width" );
+        commit.Push( wxT( "Increase Track Width" ) );
         return 0;
     }
 
@@ -803,7 +826,7 @@ int BOARD_EDITOR_CONTROL::TrackWidthDec( const TOOL_EVENT& aEvent )
             }
         }
 
-        commit.Push( "Decrease Track Width" );
+        commit.Push( wxT( "Decrease Track Width" ) );
         return 0;
     }
 
@@ -881,7 +904,7 @@ int BOARD_EDITOR_CONTROL::ViaSizeInc( const TOOL_EVENT& aEvent )
             }
         }
 
-        commit.Push( "Increase Via Size" );
+        commit.Push( wxT( "Increase Via Size" ) );
     }
     else
     {
@@ -1315,7 +1338,7 @@ int BOARD_EDITOR_CONTROL::PlaceTarget( const TOOL_EVENT& aEvent )
 
             BOARD_COMMIT commit( m_frame );
             commit.Add( target );
-            commit.Push( "Place a layer alignment target" );
+            commit.Push( wxT( "Place a layer alignment target" ) );
 
             preview.Remove( target );
 
@@ -1348,8 +1371,8 @@ int BOARD_EDITOR_CONTROL::PlaceTarget( const TOOL_EVENT& aEvent )
 }
 
 
-static bool mergeZones( BOARD_COMMIT& aCommit, std::vector<ZONE*>& aOriginZones,
-                        std::vector<ZONE*>& aMergedZones )
+static bool mergeZones( EDA_DRAW_FRAME* aFrame, BOARD_COMMIT& aCommit,
+                        std::vector<ZONE*>& aOriginZones, std::vector<ZONE*>& aMergedZones )
 {
     aCommit.Modify( aOriginZones[0] );
 
@@ -1361,13 +1384,14 @@ static bool mergeZones( BOARD_COMMIT& aCommit, std::vector<ZONE*>& aOriginZones,
 
     aOriginZones[0]->Outline()->Simplify( SHAPE_POLY_SET::PM_FAST );
 
-    // We should have one polygon with hole
-    // We can have 2 polygons with hole, if the 2 initial polygons have only one common corner
-    // and therefore cannot be merged (they are detected as intersecting)
-    // but we should never have more than 2 polys
-    if( aOriginZones[0]->Outline()->OutlineCount() > 1 )
+    // We should have one polygon, possibly with holes.  If we end up with two polygons (either
+    // because the intersection was a single point or because the intersection was within one of
+    // the zone's holes) then we can't merge.
+    if( aOriginZones[0]->Outline()->IsSelfIntersecting()
+            || aOriginZones[0]->Outline()->OutlineCount() > 1 )
     {
-        wxLogMessage( "BOARD::mergeZones error: more than 2 polys after merging" );
+        DisplayErrorMessage( aFrame, _( "Zones have insufficient overlap for merging." ) );
+        aCommit.Revert();
         return false;
     }
 
@@ -1411,28 +1435,43 @@ int BOARD_EDITOR_CONTROL::ZoneMerge( const TOOL_EVENT& aEvent )
         netcode = curr_area->GetNetCode();
 
         if( firstZone->GetNetCode() != netcode )
+        {
+            wxLogMessage( _( "Some zone netcodes did not match and were not merged." ) );
             continue;
+        }
 
         if( curr_area->GetPriority() != firstZone->GetPriority() )
+        {
+            wxLogMessage( _( "Some zone priorities did not match and were not merged." ) );
             continue;
+        }
 
         if( curr_area->GetIsRuleArea() != firstZone->GetIsRuleArea() )
+        {
+            wxLogMessage( _( "Some zones were rule areas and were not merged." ) );
             continue;
+        }
 
         if( curr_area->GetLayer() != firstZone->GetLayer() )
+        {
+            wxLogMessage( _( "Some zone layer sets did not match and were not merged." ) );
             continue;
+        }
 
         if( !board->TestZoneIntersection( curr_area, firstZone ) )
+        {
+            wxLogMessage( _( "Some zones did not intersect and were not merged." ) );
             continue;
+        }
 
         toMerge.push_back( curr_area );
     }
 
     m_toolMgr->RunAction( PCB_ACTIONS::selectionClear, true );
 
-    if( mergeZones( commit, toMerge, merged ) )
+    if( mergeZones( m_frame, commit, toMerge, merged ) )
     {
-        commit.Push( "Merge zones" );
+        commit.Push( wxT( "Merge zones" ) );
 
         for( EDA_ITEM* item : merged )
             m_toolMgr->RunAction( PCB_ACTIONS::selectItem, true, item );
