@@ -1188,6 +1188,18 @@ bool ZONE_FILLER::computeRawFilledArea( const ZONE* aZone,
     if( half_min_width - epsilon > epsilon )
         aRawPolys.Deflate( half_min_width - epsilon, numSegs, cornerStrategy );
 
+    // Min-thickness is the web thickness.  On the other hand, a blob min-thickness by
+    // min-thickness is not useful.  Since there's no obvious definition of web vs. blob, we
+    // arbitrarily choose "at least 1/2 min-thickness on one axis".
+    for( int ii = aRawPolys.OutlineCount() - 1; ii >= 0; ii-- )
+    {
+        std::vector<SHAPE_LINE_CHAIN>& island = aRawPolys.Polygon( ii );
+        EDA_RECT                       islandExtents = island.front().BBox();
+
+        if( islandExtents.GetSizeMax() < half_min_width )
+            aRawPolys.DeletePolygon( ii );
+    }
+
     DUMP_POLYS_TO_COPPER_LAYER( aRawPolys, In9_Cu, wxT( "deflated" ) );
 
     if( m_progressReporter && m_progressReporter->IsCancelled() )
